import sys
from typing_extensions import Annotated
from json import dumps

import typer
from rich import print as pprint

from gacsco.server import Server
from gacsco.utils import AsyncTyper, GacscoError

app = AsyncTyper()

server = Server()


@app.callback()
async def main(name: Annotated[str | None, typer.Option(help="Your name")] = None):
    try:
        ...
        # await server.login()
    except GacscoError as err:
        pprint(err)
        sys.exit(1)

    if name is not None:
        pprint(f"Hello {name} from genieacs-commander!")


@app.command(help="List devices")
async def list():
    try:
        resp = await server.list_devices()
        print(dumps(resp))
    except GacscoError as err:
        pprint(err)


@app.command(help="Reset the device")
def reset(): ...


@app.command(help="Get info on the device")
async def info(
    device_id: Annotated[str, typer.Argument(help="device_id or WAN MAC address")],
):
    """Get device info, from its device_id or WAN interface MAC address"""
    try:
        resp = await server.get_device_info(device_id)
        print(dumps(resp))
    except GacscoError as err:
        pprint(err)


app()
