from json import dumps

import httpx
from netaddr import EUI, AddrFormatError

from gacsco.config import conf


class LoginError(Exception):
    pass


class Server:
    _api_url: str
    cookies: httpx.Cookies = httpx.Cookies()

    def __init__(self) -> None:
        self.api_url = conf.connection.url + "/api"
        self.url = conf.connection.url

    async def login(self):
        async with httpx.AsyncClient(cookies=self.cookies) as client:
            breakpoint()
            resp = await client.post(
                f"{conf.connection.url}/login",
                data={
                    "username": conf.connection.username,
                    "password": conf.connection.password,
                },
            )
            if resp.is_success:
                self.cookies = resp.cookies
            else:
                raise LoginError(f"cannot login: {resp.text}")

    async def list_devices(self):
        async with httpx.AsyncClient(cookies=self.cookies) as client:
            resp = await client.get(f"{self.url}/devices", cookies=self.cookies)
            return resp.json()

    async def get_device_info(self, device_id: str):
        try:
            EUI(device_id)
        except AddrFormatError:
            query = {"_id": device_id}
        else:
            query = {
                "InternetGatewayDevice.WANDevice.1.WANConnectionDevice.1.WANIPConnection.1.MACAddress": device_id
            }
        async with httpx.AsyncClient(cookies=self.cookies) as client:
            resp = await client.get(
                f"{self.url}/devices/?",
                params={"query": dumps(query)},
                cookies=self.cookies,
            )
            return resp.json()
